yakumo.neutron.v2.metering.rule.Manager

Package yakumo :: Package neutron :: Package v2 :: Package metering :: Module rule :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for metering label rules for Networking v2 API

Nested Classes | [hide private]
| resource_class Resource class for metering label rules for Networking v2 API

Instance Methods | [hide private]
yakumo.base.Resource |
create(self, remote_ip_prefix=`'``__UNDEF__``'`, direction=`'``__UNDEF__``'`, is_excluded=`'``__UNDEF__``'`, metering_label=`'``__UNDEF__``'`) Create a metering label rule | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _hidden_methods = ``[``'``update``'``]``
| _json_resource_key = ``'``"metering_label_rule``'``
| _json_resources_key = ``'``"metering_label_rules``'``
| _url_resource_path = ``'``/v2.0/metering/metering-label-rules``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, remote_ip_prefix=`'``__UNDEF__``'`, direction=`'``__UNDEF__``'`, is_excluded=`'``__UNDEF__``'`, metering_label=`'``__UNDEF__``'`) | source code
Create a metering label rule :param remote_ip_prefix=: Remote IP prefix (str) :param direction=: Direction; 'ingress' or 'egress' (str) :param is_excluded=: Is the rule excluded (bool) :param metering_label=: MeteringLabel object Returns: yakumo.base.Resource Resource object (empty) Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('remote_ip_prefix', 'remote_ip_prefix', m
      apper.Noop), ('direction', 'direction', mapper.Noop), ('excluded', 'ex
      cluded', mapper.Noop), ('metering_label', 'metering_label_id', mapper.
      Resource('neutron.metering.label')),]